summaryrefslogtreecommitdiffstats
path: root/app/x11_util.h
diff options
context:
space:
mode:
Diffstat (limited to 'app/x11_util.h')
-rw-r--r--app/x11_util.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/app/x11_util.h b/app/x11_util.h
index 1c8685f1..5c202f3 100644
--- a/app/x11_util.h
+++ b/app/x11_util.h
@@ -78,9 +78,11 @@ int BitsPerPixelForPixmapDepth(Display* display, int depth);
bool IsWindowVisible(XID window);
// Returns the bounds of |window|.
bool GetWindowRect(XID window, gfx::Rect* rect);
// Get the value of an int or string property. On success, true is returned and
// the value is stored in |value|.
bool GetIntProperty(XID window, const std::string& property_name, int* value);
+bool GetIntArrayProperty(XID window, const std::string& property_name,
+ std::vector<int>* value);
bool GetStringProperty(
XID window, const std::string& property_name, std::string* value);
@@ -78,9 +78,11 @@ int BitsPerPixelForPixmapDepth(Display* display, int depth);
// Returns the bounds of |window|.
bool GetWindowRect(XID window, gfx::Rect* rect);
-// Get the value of an int or string property. On success, true is returned and
-// the value is stored in |value|.
+// Get the value of an int, int array, or string property. On
+// success, true is returned and the value is stored in |value|.
bool GetIntProperty(XID window, const std::string& property_name, int* value);